==> jc-1.4.0.tar.gz: soot/grimp/internal/AbstractGrimpIntLongBinopExpr.h <==
// public abstract class soot.grimp.internal.AbstractGrimpIntLongBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5db408cd5e821f4f soot_grimp_internal_AbstractGrimpIntLongBinopExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractIntLongBinopExpr

#include "soot/jimple/internal/AbstractIntLongBinopExpr.h"

#ifndef _JC_soot_grimp_internal_AbstractGrimpIntLongBinopExpr_H_
#define _JC_soot_grimp_internal_AbstractGrimpIntLongBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object;

typedef const struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$_init$76c8b23810ae9526(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jint _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$toString$19cdbf3266be800b(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method_info$toString$19cdbf3266be800b;

// Virtual methods structure
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods {
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$19cdbf3266be800b)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
};

// Vtype
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs {
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object {
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype	*vtype;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_AbstractGrimpIntLongBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$class_object;

#endif	/* _JC_soot_grimp_internal_AbstractGrimpIntLongBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/AbstractGrimpIntLongBinopExpr.h <==
// public abstract class soot.grimp.internal.AbstractGrimpIntLongBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5db408cd5e821f4f soot_grimp_internal_AbstractGrimpIntLongBinopExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractIntLongBinopExpr

#include "soot/jimple/internal/AbstractIntLongBinopExpr.h"

#ifndef _JC_soot_grimp_internal_AbstractGrimpIntLongBinopExpr_H_
#define _JC_soot_grimp_internal_AbstractGrimpIntLongBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object;

typedef const struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable;
typedef const struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$_init$76c8b23810ae9526(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method$toString$19cdbf3266be800b(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$method_info$toString$19cdbf3266be800b;

// Virtual methods structure
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods {
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$19cdbf3266be800b)(_jc_env *, struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
};

// Vtype
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs {
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$object {
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype	*vtype;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vtype _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_AbstractGrimpIntLongBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$class_object;

#endif	/* _JC_soot_grimp_internal_AbstractGrimpIntLongBinopExpr_H_ */
